#! /bin/sh
# version 2
## using iptables to block port on tomcat so that 
## LAG can redirect to working SSLVPN

#  user can freely change these values according to his
#  deployment
HEALTH_CHECK_TIMER=3s
SSLVPN_TOMCAT_PORT=8080
HOST=localhost
PORT=3423

# dev paths
STATUS_XPATH=//exHealth/@exHealthStatus
PIPE=/var/run/sslvpn-heartbeat
PID_PATH=/var/run/sslvpn-heartbeat.pid
SSLVPN_CHAIN=sslvpn-heartbeat-chain

daemonize () {
	echo $$ > $PID_PATH
	DOEXIT=0
	trap "{ DOEXIT=1; }" INT

	iptables -D INPUT -j $SSLVPN_CHAIN > /dev/null 2>&1|| :
	iptables -X $SSLVPN_CHAIN > /dev/null 2>&1 || :
	iptables -N $SSLVPN_CHAIN
	iptables -I INPUT -j $SSLVPN_CHAIN

	mknod $PIPE p
	while [ $DOEXIT != 1 ]
	do
		HEALTH=`w3m -dump http://$HOST:$PORT/Ex?Health:/cfg/all > $PIPE 2>/dev/null | /opt/novell/devman/jcc/utils/xmlmod $PIPE $STATUS_XPATH 2>/dev/null`
		#echo $HEALTH
		case "$HEALTH" in
			[Yy]*)
				count=`iptables -L $SSLVPN_CHAIN | wc -l`
				if [ $count > 2 ]; then 
					iptables -F $SSLVPN_CHAIN
				fi
				;;
			[Rr]*)
				count=`iptables -L $SSLVPN_CHAIN | wc -l`
				if [ $count -le 2 ]; then 
					iptables -I $SSLVPN_CHAIN -p tcp --dport $SSLVPN_TOMCAT_PORT -j REJECT
				fi
				;;
			[Gg]*)
				count=`iptables -L $SSLVPN_CHAIN | wc -l`
				if [ $count > 2 ]; then 
					iptables -F $SSLVPN_CHAIN
				fi
				;;
			*)
				count=`iptables -L $SSLVPN_CHAIN | wc -l`
				if [ $count -le 2 ]; then 
					iptables -I $SSLVPN_CHAIN -p tcp --dport $SSLVPN_TOMCAT_PORT -j REJECT
				fi
				;;
		esac
		sleep $HEALTH_CHECK_TIMER
	done

	echo "exiting..."
	test -p $PIPE && rm $PIPE
	test -f $PID_PATH && rm $PID_PATH
	echo "completed."
}

start ()
{
	test -f $PID_PATH &&  {
		PID=`cat $PID_PATH`
		echo "SSLVPN Heartbeat is already running... ($PID)"
		exit 2
	}
	echo "Starting..."
	daemonize
}

stop ()
{
	echo "Stopping..."
	test ! -f $PID_PATH &&  {
		echo "SSLVPN Heartbeat is not running..."
		exit 2
	}
	iptables -D INPUT -j $SSLVPN_CHAIN || :
	iptables -X $SSLVPN_CHAIN || :
	PID=`cat $PID_PATH`
	kill -s INT $PID
}


case $1 in
	start)
		start
		;;
	stop)
		stop
		;;
	restart)
		stop
		sleep 10s
		start
		;;
	*)
		echo "Usage: start|stop|restart"
		exit 1
		;;
esac
exit $?
